@@ -1,10 +1,8 @@
 import typing as T
 from uuid import UUID
-from enum import Enum
 from datetime import datetime, timedelta
-from decimal import Decimal
+from zoneinfo import ZoneInfo
 import json
-import orjson
 from fastapi.encoders import jsonable_encoder
 import edgedb
 from devtools import debug
@@ -692,7 +690,7 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
     ) -> T.Optional[ThisNodeType]:
         if update_last_updated:
             if is_unset(getattr(patch, "last_updated", None)):
-                patch.last_updated = datetime.utcnow()
+                patch.last_updated = datetime.now(tz=ZoneInfo("America/New_York"))
         update_d = cls.build_update_d_from_patch(patch=patch)
         set_links_d = make_set_links_d(model=patch, model_d=update_d)
         if not update_d and not set_links_d:
